# Copyrights 2001-2009 by Mark Overmeer.
#  For other contributors see ChangeLog.
# See the manual pages for details on the licensing terms.
# Pod stripped from pm file by OODoc 1.06.

use strict;
use warnings;

package Mail::Server;
use vars '$VERSION';
$VERSION = '2.092';

use base 'Mail::Reporter';


1;
